@@ -1,3 +1,4 @@
+from speechpro.cloud.speech.common.rest.cloud_client.models.auth_status_dto import AuthStatusDto
 from speechpro.cloud.speech.common.rest.cloud_client import SessionApi, AuthRequestDto
 
 
@@ -9,10 +10,18 @@ class SpeechproApiClientBase:
         self._session_id = None
 
 
+    def _check_session_status(self) -> bool:
+        session_api = SessionApi()
+        status: AuthStatusDto = session_api.check(self._session_id)
+        return status.is_active
+
+
     @property
     def session_id(self):
-        if not self._session_id:
+        if self._session_id and self._check_session_status():
+            return self._session_id
+        else:
             session_api = SessionApi()
             credentials = AuthRequestDto(self.username, self.domain_id, self.password)
             self._session_id = session_api.login(credentials).session_id
-        return self._session_id
\ No newline at end of file
+            return self._session_id
\ No newline at end of file
